function Dx = calcDx(Ds,cdf,x)

% Dx = calcDx(Ds,cdf,x)
%
% Calculates the xth percentile from a cumulative grain size distribution.
%
% inputs:
%   Ds: grain size vector (mm)
%   cdf: cumulative distribution function (0-100)
%   x: desired percentile (0-100)


% make sure Ds and cdf are column vectors of the same size
[r,c]=size(Ds);
if c > 1
    Ds = Ds';
end
[r,c] = size(cdf);
if c > 1
    cdf = cdf';
end
if length(Ds) ~= length(cdf)
    error('Error: Ds and cdf must be the same size');
end
% if min(cdf) ~= 0 || max(cdf) ~= 100
%     error('Error: cdf vector must range from 0 to 100')
% end

% sort the vectors
Ds = sort(Ds);
cdf = sort(cdf);

psi = log2(Ds);

% locate the elements that bound Dx
psi_hi = psi(min(find(cdf >= x)));
psi_lo = psi(max(find(cdf <= x)));
cdf_hi = cdf(min(find(cdf >= x)));
cdf_lo = cdf(max(find(cdf <= x)));

if psi_hi == psi_lo || cdf_hi == cdf_lo
    Dx = 2.^psi_hi;
else
    psi_x = (x - cdf_lo)*(psi_hi - psi_lo)/(cdf_hi - cdf_lo) + psi_lo;
    Dx = 2.^psi_x;
end