function sig = calcSig(Ds,cdf)

% Dg = calcDg(Ds,cdf)
%
% Calculates the geometric mean from a cumulative grain size distribution.
%
% inputs:
%   Ds: grain size vector (mm)
%   cdf: cumulative distribution function (0-100)


% make sure Ds and cdf are column vectors of the same size
[r,c]=size(Ds);
if c > 1
    Ds = Ds';
end
[r,c] = size(cdf);
if c > 1
    cdf = cdf';
end
if length(Ds) ~= length(cdf)
    error('Error: Ds and cdf must be the same size');
end
% if min(cdf) ~= 0 || max(cdf) ~= 100
%     error('Error: cdf vector must range from 0 to 100')
% end

% sort the vectors
Ds = sort(Ds);
cdf = sort(cdf);

[Di,pdf] = cdf2pdf(Ds,cdf); %pdf is in fraction, not percent

psi_i = log2(Di);
psi_g = sum(psi_i.*pdf);

sig = 2.^sqrt(sum((psi_i - psi_g).^2 .* pdf));
