function [Di,pdf] = cdf2pdf(Ds,cdf)
%
% [Di,pdf] = cdf2pdf(Ds,cdf)
% 
% Converts a cumulative gsd to a pdf.
%
% inputs: 
%   Ds: grain size vector (mm)
%   cdf: cdf vector (percent) - must be from 0 to 100
%
% outputs:
%   Di: pdf grain size vector
%   pdf: pdf vector (fraction - will be from 0 to 1)

% make sure Ds and cdf are column vectors of the same size
switchflag = 0;
[r,c]=size(Ds);
if c > 1
    Ds = Ds';
    switchflag = 1;
end
[r,c] = size(cdf);
if c > 1
    cdf = cdf';
    switchflag = 1;
end
if length(Ds) ~= length(cdf)
    error('Error: Ds and cdf must be the same size');
end
% if min(cdf) ~= 0 || max(cdf) ~= 100
%     error('Error: cdf vector must range from 0 to 100')
% end

% sort the vectors
Ds = sort(Ds);
cdf = sort(cdf);

psi = log2(Ds);

N = length(Ds)-1;
Di = zeros(N,1);
pdf = zeros(N,1);
for m=1:N
    Di(m) = sqrt(Ds(m)*Ds(m+1));
    pdf(m) = (cdf(m+1)-cdf(m))/100;
end

% switch back to row vectors if that was the input
if switchflag == 1
    Di = Di';
    pdf = pdf';
end