%find_load_WC.m
% wilcock-crowe bedload relation
% surf_cdf needs to be between 0 and 100, rather than 0 and 1

function [qbT,load_cdf] = find_load_WC_2(ustar,Db,surf_cdf)

%first sort the gsd to avoid spurious imaginary results
Db = sort(Db);
surf_cdf = sort(surf_cdf);

%compute sand fraction
psib = log2(Db);
sandfrac = interp1(psib,surf_cdf,1)/100;



%constants or inputs that may be changed....
Rr = 1.65; %submerged specific gravity of gravel
rhos = 2650;
rhow = 1000;
g = 9.81;
lowphi = 0.1;

% generate characteristic grain size classes and surface pdf
N = length(Db)-1;
for m=1:N
    D(m) = sqrt(Db(m)*Db(m+1));
    F(m) = (surf_cdf(m+1)-surf_cdf(m))/100;
end
psi = log2(D); 

%calculate geometric mean of surface
psibar = sum(psi.*F);
Dsg = 2^psibar;

%hiding function
b = 0.67./(1+exp(1.5-D./Dsg));
taustar_rm = 0.021 + 0.015 * exp(-20 * sandfrac);
taurm = taustar_rm * (rhos/rhow - 1)*rhow*g*(Dsg/1000);
taur = taurm.*(D./Dsg).^b;
tau = rhow*ustar^2;
phi = tau./taur;
W = G(phi);
qb = W.*F.*(ustar^3)./((rhos/rhow - 1)*g);

%calculate total load qbT
qbT = sum(qb);

%calculate fractions p(i) of each size class in the load
p = qb/qbT;

%account for low phi...
taustarg = tau/(rhos-rhow)/g/(Dsg/1000);
phisgo = taustarg/taustar_rm;
if phisgo < lowphi
    qbT = 0;
    p(:) = 1/N;
end

%calculate the load cdf (corresponding to Db) from fractions p(i)
%FIXED MAY 2008
load_cdf(1) = 0;
for m=2:N+1
    load_cdf(m) = load_cdf(m-1) + 100*p(m-1);
end

%%%%%%
function W = G(phi)

for i=1:length(phi)
    if phi(i)<1.35
        W(i) = 0.002*phi(i)^7.5;
    else
        W(i) = 14*(1-0.894/phi(i)^0.5)^4.5;
    end
end
