%  UPDATED 09/08 - shouldn't need set_strain_curves m file anymore
%  this should be able to calculate the flux and gsd of the load using the
%  parker (1990) surface based bedload transport equations.  Required
%  inputs are the shear velocity ustar, and the surface grain size
%  distribution [D, Ff] where D is a vector of the grain size classes and
%  surf_cdf
%  is the percent finer than each size class.  for now, it is necessary that this
%  gsd be concatenated and renormalized with a lower bound of 2 mm.
%  note: D needs to be in ascending order, and surf_cdf should be bounded
%  by 0 and 100

% This can be run on its own.

% Gravel is divided into N size ranges bounded by N+1 sizes

%ADJUST TO PUT IN LOW PHI??

function [qbT,load_cdf] = find_load_parker_2(ustar,Db,surf_cdf)

%global Rr g;

%constants or inputs that may be changed....
Rr = 1.65; %submerged specific gravity of gravel
g = 9.81;
taustar_ssrg = 0.0386;
beta = 0.0951;
lowphi = 0.1;

% generate characteristic grain size classes and surface pdf
%first sort the gsd so we don't get spurious imaginary results
Db = sort(Db);
surf_cdf = sort(surf_cdf);
N = length(Db)-1;
for m=1:N
    D(m) = sqrt(Db(m)*Db(m+1));
    F(m) = (surf_cdf(m+1)-surf_cdf(m))/100;
end
psi = log2(D); 

%calculate geometric mean of surface
psibar = sum(psi.*F);
Dsg = 2^psibar;

%calculate geometric and arithmetic standard deviation of surface
sigma = sqrt(sum(((psi-psibar).^2).*F));
%sigmag = 2^sigma; %commented because this variable is never used...

%calculate phisgo
taustar_sg = ustar^2/(Rr*g*(Dsg/1000));
phisgo = taustar_sg / taustar_ssrg;

%calculate omega
[po,oo,so]=set_strain_curves(); %make sure this m-file is in the directory
if phisgo > po(35)
    omegao = oo(35) + (oo(36) - oo(35)) / (po(36) - po(35))...
        * (phisgo - po(35));
    sigo = so(35) + (so(36) - so(35)) / (po(36) - po(35))...
        * (phisgo - po(35));
else
    if phisgo <= 0.7639
        omegao = 1.011;
        sigo = 0.8157;
    else
        kk=max(find(phisgo > po));
        x1 = po(kk-1); x2 = po(kk); x3 = po(kk+1); x4 = po(kk+2);
        y1 = oo(kk-1); y2 = oo(kk); y3 = oo(kk+1); y4 = oo(kk+2);
        omegao = cubic_interpolator(phisgo,x1,x2,x3,x4,y1,y2,y3,y4);
        y1 = so(kk-1); y2 = so(kk); y3 = so(kk+1); y4 = so(kk+2);
        sigo = cubic_interpolator(phisgo,x1,x2,x3,x4,y1,y2,y3,y4);
    end
end
omega = 1 + sigma/sigo * (omegao-1);

%calculate phi matrix
phi = omega*phisgo*(D/Dsg).^(-beta);

%calculate qb matrix (gives flux for each size class)
qb = 0.00218*G(phi).*F.*(ustar^3)/Rr/g;

%calculate total load qbT
qbT = sum(qb);

%calculate fractions p(i) of each size class in the load
p = qb/qbT;

%account for low phi...
if phisgo < lowphi
    qbT = 0;
    p(:) = 1/N;
end

%calculate the load cdf (corresponding to Db) from fractions p(i)
%NEW MAY 2008 - FOUND PROBLEM WITH THIS, FIXED IT
%wasn't calculating load cdf correctly b/c the 
load_cdf(1) = 0;
for m=2:N+1
    load_cdf(m) = load_cdf(m-1) + 100*p(m-1);
end

end



%%%%%%%%%%%%%%%%%%%%555
% subfunction cubic_interpolator for finding omega
function yout = cubic_interpolator(phisgo,xm1,x,xp1,xp2,ym1,y,yp1,yp2)
a1 = ym1;
a2 = (y - a1) / (x - xm1);
a3 = (yp1 - a1 - a2 * (xp1 - xm1)) / ...
    (xp1 - xm1) / (xp1 - x);
a4 = yp2 - a1 - a2 * (xp2 - xm1) ...
     - a3 * (xp2 - xm1) * (xp2 - x);
a4 = a4 / (xp2 - xm1) / (xp2 - x) / (xp2 - xp1);
yout = a1 + a2 * (phisgo - xm1) + a3 * (phisgo - xm1) * (phisgo - x) ...
    + a4 * (phisgo - xm1) * (phisgo - x) * (phisgo - xp1);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%subfunction G(phi)
function out = G(phi)

for i=1:length(phi)
    if phi(i)<1
        out(i) = phi(i)^14.2;
    else if phi(i) <=1.59
            out(i) = exp((14.2*(phi(i)-1)) - (9.28*((phi(i)-1)^2)));
        else
            out(i) = 5474*(1-0.853/phi(i))^4.5;
        end
    end
end

end

%%%%%%%%%%%%%%%%%%%%%%%%%

%set_strain_curves.m
    % these are the interpolation points for the functions omegaoak and sigoak of the bedload
    % formula of Parker
    function [po,oo,so] = set_strain_curves()
        po(1) = 0.6684;   oo(1) = 1.011;    so(1) = 0.8157;
        po(2) = 0.7639;   oo(2) = 1.011;    so(2) = 0.8157;
        po(3) = 0.8601;   oo(3) = 1.01;     so(3) = 0.8182;
        po(4) = 0.9096;   oo(4) = 1.008;    so(4) = 0.8233;
        po(5) = 0.9615;   oo(5) = 1.004;    so(5) = 0.8333;
        po(6) = 1.0;      oo(6) = 0.9997;   so(6) = 0.8439;
        po(7) = 1.055;    oo(7) = 0.9903;   so(7) = 0.8621;
        po(8) = 1.108;    oo(8) = 0.9789;   so(8) = 0.8825;
        po(9) = 1.197;    oo(9) = 0.9567;   so(9) = 0.9214;
        po(10) = 1.302;   oo(10) = 0.9273;  so(10) = 0.9723;
        po(11) = 1.407;   oo(11) = 0.8964;  so(11) = 1.025;
        po(12) = 1.529;   oo(12) = 0.8604;  so(12) = 1.083;
        po(13) = 1.641;   oo(13) = 0.8287;  so(13) = 1.13;
        po(14) = 1.702;   oo(14) = 0.8123;  so(14) = 1.153;
        po(15) = 1.832;   oo(15) = 0.7796;  so(15) = 1.196;
        po(16) = 1.937;   oo(16) = 0.7554;  so(16) = 1.225;
        po(17) = 2.044;   oo(17) = 0.7326;  so(17) = 1.25;
        po(18) = 2.261;   oo(18) = 0.6928;  so(18) = 1.287;
        po(19) = 2.499;   oo(19) = 0.6585;  so(19) = 1.313;
        po(20) = 2.732;   oo(20) = 0.6345;  so(20) = 1.333;
        po(21) = 2.993;   oo(21) = 0.615;   so(21) = 1.352;
        po(22) = 3.477;   oo(22) = 0.5877;  so(22) = 1.38;
        po(23) = 4.075;   oo(23) = 0.564;   so(23) = 1.403;
        po(24) = 4.469;   oo(24) = 0.5523;  so(24) = 1.414;
        po(25) = 5.016;   oo(25) = 0.5395;  so(25) = 1.426;
        po(26) = 6.158;   oo(26) = 0.5209;  so(26) = 1.444;
        po(27) = 7.821;   oo(27) = 0.5045;  so(27) = 1.458;
        po(28) = 10.06;   oo(28) = 0.4917;  so(28) = 1.469;
        po(29) = 14.38;   oo(29) = 0.479;   so(29) = 1.48;
        po(30) = 19.97;   oo(30) = 0.4712;  so(30) = 1.486;
        po(31) = 25.79;   oo(31) = 0.4668;  so(31) = 1.49;
        po(32) = 38.57;   oo(32) = 0.462;   so(32) = 1.493;
        po(33) = 68.74;   oo(33) = 0.4578;  so(33) = 1.497;
        po(34) = 91.95;   oo(34) = 0.4564;  so(34) = 1.498;
        po(35) = 231.2;   oo(35) = 0.4541;  so(35) = 1.499;
        po(36) = 2320.0;  oo(36) = 0.4527;  so(36) = 1.5;
    end



